
from PyQt4.QtCore import QSettings, QVariant, Qt, SIGNAL
from PyQt4.QtGui import QDialog, QFileDialog

from Ui_Base_LoadThemAll import Ui_Base_LoadThemAll

class Base_LoadThemAllDialog( QDialog, Ui_Base_LoadThemAll ):
  """ A generic class to be reused in vector and raster dialogs """
  def __init__( self, isVector ):
    QDialog.__init__( self ) 
    self.setupUi( self )
    self.isVector = isVector # To know if it should be started with vector parameters
    self.loadFormats( self.isVector )
    self.connect( self.btnBaseDir, SIGNAL( "clicked()" ), self.selectDir )

  def selectDir( self ):
    """ Open a dialog for the user to choose a starting directory """
    settings = QSettings()
    if self.isVector:
      path = QFileDialog.getExistingDirectory( self, self.tr( "Select a base directory" ), 
        settings.value( "/Load_Them_All/vector/path" ).toString(), QFileDialog.ShowDirsOnly )
    else:
      path = QFileDialog.getExistingDirectory( self, self.tr( "Select a base directory" ), 
        settings.value( "/Load_Them_All/raster/path" ).toString(), QFileDialog.ShowDirsOnly )
    if path: self.txtBaseDir.setText( path )

  def loadFormats( self, isVector ):
    """ Fill the comboBox with file formats """
    if isVector:
      self.cboFormats.addItem( "All listed formats (*.*)", QVariant( [".shp", ".mif", ".tab", ".dgn", ".vrt", ".csv", ".gml", ".gpx", ".kml", ".geojson", ".gmt", ".sqlite", ".e00", ".dxf", ".xml"] ) )
      self.cboFormats.addItem( "ESRI Shapefile (*.shp)", QVariant( [".shp"] ) )
      self.cboFormats.addItem( "Mapinfo File (*.mif, *.tab)", QVariant( [".mif", ".tab"] ) )
      self.cboFormats.addItem( "Microstation DGN (*.dgn)", QVariant( [".dgn"] ) )
      self.cboFormats.addItem( "VRT - Virtual Datasource (*.vrt)", QVariant( [".vrt"] ) )
      self.cboFormats.addItem( "Comma Separated Value (*.csv)", QVariant( [".csv"] ) )
      self.cboFormats.addItem( "Geography Markup Language (*.gml)", QVariant( [".gml"] ) )
      self.cboFormats.addItem( "GPX (*.gpx)", QVariant( [".gpx"] ) )
      self.cboFormats.addItem( "KML - Keyhole Markup Language (*.kml)", QVariant( [".kml"] ) )
      self.cboFormats.addItem( "GeoJSON (*.geojson)", QVariant( [".geojson"] ) )
      self.cboFormats.addItem( "GMT (*.gmt)", QVariant( [".gmt"] ) )
      self.cboFormats.addItem( "SQLite (*.sqlite)", QVariant( [".sqlite"] ) )
      self.cboFormats.addItem( "Arc/Info ASCII Coverage (*.e00)", QVariant( [".e00"] ) )
      self.cboFormats.addItem( "AutoCAD DXF (*.dxf)", QVariant( [".dxf"] ) )
      self.cboFormats.addItem( "GeoRSS (*.xml)", QVariant( [".xml"] ) ) 
    else:
      self.cboFormats.addItem( "All listed formats (*.*)", QVariant( [".vrt", ".tif", ".tiff", ".img", ".asc", ".png", ".jpg", ".jpeg", ".gif", ".xpm", ".bmp", ".pix", ".map", ".mpr", ".mpl", ".hgt", ".nc", ".grb", ".rst", ".grd", ".rda", ".hdr", ".dem", ".blx", ".sqlite", ".sdat"] ) )
      self.cboFormats.addItem( "Virtual Raster (*.vrt)", QVariant( [".vrt"] ) )
      self.cboFormats.addItem( "GeoTIFF (*.tif, *.tiff)", QVariant( [".tif", ".tiff"] ) )
      self.cboFormats.addItem( "Erdas Imagine Images (*.img)", QVariant( [".img"] ) )
      self.cboFormats.addItem( "Arc/Info ASCII Grid (*.asc)", QVariant( [".asc"] ) )
      self.cboFormats.addItem( "Portable Network Graphics (*.png)", QVariant( [".png"] ) )
      self.cboFormats.addItem( "JPEG JFIF (*.jpg, *.jpeg)", QVariant( [".jpg", ".jpeg"] ) )
      self.cboFormats.addItem( "Graphics Interchange Format (*.gif)", QVariant( [".gif"] ) )
      self.cboFormats.addItem( "X11 PixMap Format (*.xpm)", QVariant( [".xpm"] ) )
      self.cboFormats.addItem( "MS Windows Device Independent Bitmap (*.bmp)", QVariant( [".bmp"] ) )
      self.cboFormats.addItem( "PCIDSK Database File (*.pix)", QVariant( [".pix"] ) )
      self.cboFormats.addItem( "PCRaster Raster File (*.map)", QVariant( [".map"] ) )
      self.cboFormats.addItem( "ILWIS Raster Map (*.mpr, *.mpl)", QVariant( [".mpr", ".mpl"] ) )
      self.cboFormats.addItem( "SRTMHGT File Format (*.hgt)", QVariant( [".hgt"] ) )
      self.cboFormats.addItem( "GMT NetCDF Grid Format (*.nc)", QVariant( [".nc"] ) )
      self.cboFormats.addItem( "GRIdded Binary (*.grb)", QVariant( [".grb"] ) )
      self.cboFormats.addItem( "Idrisi Raster A.1 (*.rst)", QVariant( [".rst"] ) )
      self.cboFormats.addItem( "Golden Software ASCII Grid (*.grd)", QVariant( [".grd"] ) )
      self.cboFormats.addItem( "R Object Data Store (*.rda)", QVariant( [".rda"] ) )
      self.cboFormats.addItem( "Vexcel MFF Raster (*.hdr)", QVariant( [".hdr"] ) )
      self.cboFormats.addItem( "USGS Optional ASCII DEM (*.dem)", QVariant( [".dem"] ) )
      self.cboFormats.addItem( "Magellan topo (*.blx)", QVariant( [".blx"] ) )
      self.cboFormats.addItem( "Rasterlite (*.sqlite)", QVariant( [".sqlite"] ) )
      self.cboFormats.addItem( "SAGA GIS Binary Grid (*.sdat)", QVariant( [".sdat"] ) )

  def keyPressEvent( self, e ):
    """ Handle the ESC key to avoid only the base dialog being closed """
    if ( e.key() == Qt.Key_Escape ):
      e.ignore()

